@@ -189,7 +189,7 @@ T_SOC smallserver_init(int* port,char* adr) {
       if ( (soc = (T_SOC) socket(SOCaddr_sinfamily(server), SOCK_STREAM, 0)) != INVALID_SOCKET) {
         SOCaddr_initport(server, *port);
         if ( bind(soc,(struct sockaddr*) &server, server_size) == 0 ) {
-          /*int len;
+          /*SOClen len;
           SOCaddr server2;
           len=sizeof(server2);*/
           // effacer structure
@@ -302,7 +302,7 @@ int smallserver(T_SOC soc,char* url,char* method,char* data, char* path) {
     };
     initStrElt initStr[] = {
       { "user", "Mozilla/4.5 (compatible; HTTrack 3.0x; Windows 98)" },
-      { "footer", "<!-- Mirrored from %s%s by HTTrack Website Copier/3.x [XR&CO'2008], %s -->" },
+      { "footer", "<!-- Mirrored from %s%s by HTTrack Website Copier/3.x [XR&CO'2013], %s -->" },
       { "url2", "+*.png +*.gif +*.jpg +*.css +*.js -ad.doubleclick.net/*" },
       { NULL, NULL }
     };
@@ -438,13 +438,11 @@ int smallserver(T_SOC soc,char* url,char* method,char* data, char* path) {
         strcatbuff(buffer, "&");
         while( s && (e = strchr(s, '=')) && (f = strchr(s, '&')) ) {
           char* ua;
-          int len;
           String sua = STRING_EMPTY;
           *e = *f = '\0';
           ua = e + 1;
           if (strfield2(ua, "on"))  /* hack : "on" == 1 */
             ua = "1";
-          len = (int) strlen(ua);
           unescapehttp(ua, &sua);
           inthash_write(NewLangList, s, (intptr_t)StringAcquire(&sua));
           s = f + 1;
